@@ -162,8 +162,8 @@ WManager::CheckArguments(int    argc,
       if(argv[i][0] == '-' && argv[i][1] == 'r') {
 	
 	// we must delete only one argument
-	*_ConfigurationFilename = "";
-	*_ConfigurationFilename += _CutString(argv[i], "-r");
+	// Skip the -r prefix.
+	*_ConfigurationFilename = argv[i]+2;
       } else {
 
 	// copy argument to new array
@@ -306,33 +306,3 @@ WManager::_TokenizeAndAddToBrowser(char* entry)
     } // end if
   } // end if
 }
-
-
-// cut rest from the beginning of str
-char*
-WManager::_CutString(const char* str, const char* rest)
-{
-  int   i          = 0;
-  int   n          = 0;
-  int   length     = 0;
-  int   new_length = 0;
-  char* new_str    = 0;
-  
-
-  length = strlen(str);
-  new_length = length - strlen(rest);
-
-  if(new_length < 0)
-    return 0;
-  
-  new_str = new char[new_length+1];
-
-  for(i = strlen(rest), n = 0;
-      i < length;
-      i++, n++) {
-    new_str[n] = str[i];
-  }
-  new_str[new_length+1] = 0;
-
-  return new_str;
-}
