@@ -35,7 +35,7 @@ main(int    argc,
      char** argv)
 {
 #if DEBUG == 1
-  cout << "wmanager: main(int, char**)\n";
+  cerr << "wmanager: main(int, char**)\n";
 #endif
 
   WManager* wm = 0;
